@@ -274,13 +274,13 @@ class _DCLosses(object):
     rear_irradiance: t.Optional[float] = opt_field()
     lid: t.Optional[float] = opt_field()
     dc_array_adjustment: t.Optional[float] = opt_field()
+    mppt_error: t.Optional[float] = opt_field()
 
 
 @dataclass_json
 @dataclass
 class ACLosses(object):
     ac_wiring: t.Optional[float] = opt_field()
-    tracking: t.Optional[float] = opt_field()
     transformer_load: t.Optional[float] = opt_field()
     transformer_no_load: t.Optional[float] = opt_field()
     transmission: t.Optional[float] = opt_field()
@@ -396,7 +396,7 @@ class PVModel(object):
     losses: t.Optional[Losses] = opt_field()
     layout: t.Optional[Layout] = opt_field()
     project_term: t.Optional[int] = None
-    array_degradation_rate: t.Optional[float] = None
+    array_degradation_rate: t.Optional[float] = opt_field()
     array_degradation_mode: t.Optional[ArrayDegradationMode] = "linear"
 
 
